//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Demo
{
	/// <summary>
	/// Summary description for AppointmentsForm.
	/// </summary>
	public partial class AppointmentsDialog : System.Windows.Forms.Form
	{
		/// <summary>
		/// Initializes a new instance of the AppointmentsDialog class.
		/// </summary>
		public AppointmentsDialog(Calendar calendar)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			_calendar = calendar;

			// Populate location list
			foreach (Item item in _calendar.Schedule.Items)
			{
				ListViewItem listItem = new ListViewItem(
					new string[]
					{
						item.HeaderText,
						item.StartTime.ToShortDateString(),
						item.EndTime.ToShortDateString()
					});
				listItem.Tag = item;
				_list.Items.Add(listItem);
			}
		}

		/// <summary>
		/// Handles the Click event of the Add button.
		/// </summary>
		private void btnAdd_Click(object sender, EventArgs e)
		{
			AppointmentForm form = new AppointmentForm(_calendar.Schedule);
			if (form.ShowDialog(this) == DialogResult.OK)
			{
				_calendar.Schedule.Items.Add(form.Appointment);

				_list.Items.Add(new ListViewItem(
					new string[]
						{
							form.Appointment.HeaderText,
							form.Appointment.StartTime.ToShortDateString(),
							form.Appointment.EndTime.ToShortDateString()
						}));
			}
		}

		/// <summary>
		/// Handles the Remove event of the Add button.
		/// </summary>
		private void btnRemove_Click(object sender, EventArgs e)
		{
			while (_list.SelectedItems.Count > 0)
			{
				_calendar.Schedule.Items.Remove(
					_list.SelectedItems[0].Tag as Item);

				_list.Items.Remove(_list.SelectedItems[0]);
			}
		}

		/// <summary>
		/// Handles the DoubleClick event of the appointment list.
		/// </summary>
		private void _list_DoubleClick(object sender, System.EventArgs e)
		{
			if (_list.SelectedItems.Count == 0)
				return;

			Appointment app = _list.SelectedItems[0].Tag as Appointment;

			AppointmentForm form = new AppointmentForm(_calendar.Schedule);
			form.SetAppointment(app);
			if (form.ShowDialog(this) == DialogResult.OK)
			{
				_list.SelectedItems[0].Text = app.HeaderText;
				_list.SelectedItems[0].SubItems[1].Text = app.StartTime.ToShortDateString();
				_list.SelectedItems[0].SubItems[2].Text = app.EndTime.ToShortDateString();
			}
		}


		private Calendar _calendar;
	}
}
