//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Demo
{
	/// <summary>
	/// Summary description for ContactsForm.
	/// </summary>
	public partial class ContactsDialog : System.Windows.Forms.Form
	{
		/// <summary>
		/// Initializes a new instance of the ContactsDialog form.
		/// </summary>
		public ContactsDialog(Calendar calendar)
		{
			InitializeComponent();

			_calendar = calendar;

			// Populate contact list
			foreach (Contact contact in _calendar.Schedule.Contacts)
			{
				ListViewItem item = new ListViewItem(
					string.Format("{0}, {1}", contact.LastName, contact.FirstName));
				item.Tag = contact;
				_list.Items.Add(item);
			}
		}

		/// <summary>
		/// Handles the Click event of the Add button.
		/// </summary>
		private void btnAdd_Click(object sender, EventArgs e)
		{
			ContactDialog dlg = new ContactDialog();
			if (dlg.ShowDialog(this) == DialogResult.OK)
			{
				Contact contact = new Contact();
				contact.FirstName = dlg.FirstName;
				contact.LastName = dlg.LastName;
				contact.Address = dlg.Address;
				contact.Email = dlg.Email;
				contact.Phone = dlg.Phone;

				_calendar.Schedule.Contacts.Add(contact);

				ListViewItem item = new ListViewItem(
					string.Format("{0}, {1}", contact.LastName, contact.FirstName));
				item.Tag = contact;
				_list.Items.Add(item);
			}
		}

		/// <summary>
		/// Handles the Click event of the Remove button.
		/// </summary>
		private void btnRemove_Click(object sender, EventArgs e)
		{
			while (_list.SelectedItems.Count > 0)
			{
				_calendar.Schedule.Contacts.Remove(
					_list.SelectedItems[0].Tag as Contact);

				_list.Items.Remove(_list.SelectedItems[0]);
			}
		}

		private void _list_DoubleClick(object sender, System.EventArgs e)
		{
			if (_list.SelectedItems.Count == 0)
				return;

			Contact contact = _list.SelectedItems[0].Tag as Contact;

			ContactDialog dlg = new ContactDialog();
			dlg.FirstName = contact.FirstName;
			dlg.LastName = contact.LastName;
			dlg.Address = contact.Address;
			dlg.Email = contact.Email;
			dlg.Phone = contact.Phone;

			if (dlg.ShowDialog(this) == DialogResult.OK)
			{
				contact.FirstName = dlg.FirstName;
				contact.LastName = dlg.LastName;
				contact.Address = dlg.Address;
				contact.Email = dlg.Email;
				contact.Phone = dlg.Phone;

				ListViewItem item = _list.SelectedItems[0];
				item.Text = string.Format("{0}, {1}", contact.LastName, contact.FirstName);
			}
		}


		private Calendar _calendar;
	}
}
