//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Printing;
using System.IO;
using System.Windows.Forms;

using MindFusion.Scheduling.Reporting;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Demo
{
	/// <summary>
	/// The main form of the application.
	/// </summary>
	public partial class MainForm : Form
	{
		/// <summary>
		/// Static constructor.
		/// </summary>
		static MainForm()
		{
			Images = new Image[]
			{
				Resources.Image1,
				Resources.Image2,
				Resources.Image3,
				Resources.Image4,
				Resources.Image5,
				Resources.Image6,
				Resources.Image7,
				Resources.Image8,
				Resources.Image9,
				Resources.Image10,
				Resources.Image11,
				Resources.Image12,
				Resources.Image13,
				Resources.Image14,
				Resources.Image15,
				Resources.Image16,
				Resources.Image17,
				Resources.Image18,
				Resources.Image19,
				Resources.Image20,
				Resources.Image21,
				Resources.Image22,
				Resources.Image23,
				Resources.Image24,
				Resources.Image25,
				Resources.Image26,
				Resources.Image27,
				Resources.Image28,
				Resources.Image29,
				Resources.Image30,
				Resources.Image31,
				Resources.Image32,
				Resources.Image33,
				Resources.Image34,
				Resources.Image35,
				Resources.Image36,
				Resources.Image37,
				Resources.Image38,
				Resources.Image39,
				Resources.Image40,
				Resources.Image41,
				Resources.Image42,
				Resources.Image43,
				Resources.Image44,
				Resources.Image45,
				Resources.Image46,
				Resources.Image47,
				Resources.Image48,
				Resources.Image49
			};
		}

		/// <summary>
		/// Initializes a new instance of the MainForm class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();

			_appPath = System.IO.Path.GetDirectoryName(Application.ExecutablePath);

			_lbInfo.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(OnDocumentCompleted);

			// Load the info
			string path = Path.GetDirectoryName(Application.ExecutablePath);
			string file = Path.Combine(path, "Info.xml");
			_info = new InfoHolder(file);

			// Initialize dates to be today
			_calendar.TimetableSettings.Dates.Clear();
			for (int i = 0; i < 5; i++)
			{
				_calendar.TimetableSettings.Dates.Add(
					DateTime.Today + new TimeSpan(i * TimeSpan.TicksPerDay));
			}
			_calendar.TimetableSettings.VisibleColumns = 4;

			_calendar.Date = DateTime.Today;
			_calendar.EndDate = DateTime.Today + TimeSpan.FromDays(60);

			_calendar.TimetableSettings.SecondTimelineOffset = 2;

			// Initialize the tree view
			TreeNode firstSelected = null;
			TreeNode node = null;
			TreeNode root = null;
			TreeNode root2 = null;

			root = new TreeNode("Timetable", 4, 4);
			firstSelected = root;
			root.Tag = 400;
			node = new TreeNode("Horizontal timetable", 5, 5);
			node.Tag = 405;
			root.Nodes.Add(node);
			node = new TreeNode("Vertical timetable", 5, 5);
			node.Tag = 406;
			root.Nodes.Add(node);
			root2 = new TreeNode("Custom drawing", 5, 5);
			root2.Tag = 420;
			node = new TreeNode("Coloring cells", 5, 5);
			node.Tag = 421;
			root2.Nodes.Add(node);
			node = new TreeNode("Embellishing the timeline", 5, 5);
			node.Tag = 422;
			root2.Nodes.Add(node);
			root.Nodes.Add(root2);
			_stepsView.Nodes.Add(root);

			root = new TreeNode("Resource view", 6, 6);
			root.Tag = 600;
			_stepsView.Nodes.Add(root);

			root = new TreeNode("Single month", 0, 0);
			root.Tag = 0;
			node = new TreeNode("Responding to user actions", 5, 5);
			node.Tag = 10;
			root.Nodes.Add(node);
			node = new TreeNode("Customizing the appearance", 5, 5);
			node.Tag = 20;
			root.Nodes.Add(node);
			_stepsView.Nodes.Add(root);

			root = new TreeNode("List View", 2, 2);
			root.Tag = 200;
			node = new TreeNode("Horizontal view", 5, 5);
			node.Tag = 210;
			root.Nodes.Add(node);
			node = new TreeNode("Vertical view", 5, 5);
			node.Tag = 220;
			root.Nodes.Add(node);
			_stepsView.Nodes.Add(root);

			root = new TreeNode("Week range", 3, 3);
			root.Tag = 300;
			node = new TreeNode("Multiple week view", 5, 5);
			node.Tag = 310;
			root.Nodes.Add(node);
			node = new TreeNode("Single week view", 5, 5);
			node.Tag = 320;
			root.Nodes.Add(node);
			_stepsView.Nodes.Add(root);

			root = new TreeNode("Month range", 1, 1);
			root.Tag = 100;
			_stepsView.Nodes.Add(root);

			root = new TreeNode("Miscellaneous", 5, 5);
			root.Tag = 500;
			node = new TreeNode("Custom item editor", 5, 5);
			node.Tag = 510;
			root.Nodes.Add(node);
			node = new TreeNode("Formatted text", 5, 5);
			node.Tag = 520;
			root.Nodes.Add(node);
			_stepsView.Nodes.Add(root);

			_stepsView.SelectedNode = firstSelected;
			_stepsView.Focus();

			_calendar.BeginInit();
			_calendar.MonthSettings.SubHeaderHeight = 20;
			_calendar.MonthSettings.WeekNumbersHeaderWidth = 20;
			_calendar.EndInit();

			_calendar.Schedule.UndoEnabled = true;

			// Create different styles for different types of events
			_taskStyle = new Style();
			_taskStyle.TextColor = Color.FromArgb(0xFF, 0x80, 0x80, 0x80);
			_taskStyle.BorderTopColor = Color.DarkOrchid;
			_taskStyle.BorderLeftColor = Color.DarkOrchid;
			_taskStyle.BorderBottomColor = Color.DarkOrchid;
			_taskStyle.BorderRightColor = Color.DarkOrchid;
			_taskStyle.LineColor = Color.DarkOrchid;
			_taskStyle.FillColor = Color.MediumOrchid;
			_taskStyle.Brush = new MindFusion.Drawing.LinearGradientBrush(
				Color.FromArgb(75, Color.White), Color.FromArgb(75, Color.Plum), 90);
			_taskStyle.HeaderTextColor = Color.DarkViolet;

			_eventStyle = new Style();
			_eventStyle.TextColor = Color.FromArgb(0xFF, 0x80, 0x80, 0x80);
			_eventStyle.BorderTopColor = Color.Goldenrod;
			_eventStyle.BorderLeftColor = Color.Goldenrod;
			_eventStyle.BorderBottomColor = Color.Goldenrod;
			_eventStyle.BorderRightColor = Color.Goldenrod;
			_eventStyle.LineColor = Color.Goldenrod;
			_eventStyle.FillColor = Color.FromArgb(250, 200, 100);
			_eventStyle.Brush = new MindFusion.Drawing.LinearGradientBrush(
				Color.White, Color.PaleGoldenrod, 90);
			_eventStyle.HeaderTextColor = Color.DarkGoldenrod;

			_freeStyle = new Style();
			_freeStyle.TextColor = Color.FromArgb(0xFF, 0x80, 0x80, 0x80);
			_freeStyle.BorderTopColor = Color.LimeGreen;
			_freeStyle.BorderLeftColor = Color.LimeGreen;
			_freeStyle.BorderBottomColor = Color.LimeGreen;
			_freeStyle.BorderRightColor = Color.LimeGreen;
			_freeStyle.LineColor = Color.LimeGreen;
			_freeStyle.FillColor = Color.PaleGreen;
			_freeStyle.Brush = new MindFusion.Drawing.LinearGradientBrush(
				Color.White, Color.LightGreen, 90);
			_freeStyle.HeaderTextColor = Color.DarkGreen;

			_pnlMonth.Dock = DockStyle.Fill;

			_pnlMonthAppearance.Dock = DockStyle.Fill;

			_pnlYear.Dock = DockStyle.Fill;

			_pnlWeek.Dock = DockStyle.Fill;

			_pnlCalendar.Dock = DockStyle.Fill;

			_pnlTimetable.Dock = DockStyle.Fill;

			_pnlTimeline.Dock = DockStyle.Fill;

			_pnlResourceView.Dock = DockStyle.Fill;

			// Register MyApp for serializarion
			Schedule.RegisterItemClass(typeof(MyApp), "myapp", 1);

			_imageHoliday = Resources.Image40;
			_imageBirthday = Resources.Image12;

			glassEffect = new GlassEffect();
			aeroEffect = new AeroEffect();
			aeroEffect.Opacity = 0.75f;

			AddScheduleData();
		}

		private void OnDocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
		{
			if (_lbInfo.Document != null)
			{
				_lbInfo.Document.Click += Document_Click;
				_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
					"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			}
		}

		/// <summary>
		/// Handles the Web browser document's Click event.
		/// </summary>
		private void Document_Click(object sender, HtmlElementEventArgs e)
		{
			e.ReturnValue = true;

			HtmlElement pointed = _lbInfo.Document.GetElementFromPoint(e.ClientMousePosition);
			if (pointed == null)
				return;

			if (pointed.TagName.ToLower() == "a")
			{
				string href = pointed.GetAttribute("href").ToLower();
				if (href.StartsWith("help:"))
				{
					string topic = href.Substring(5);
					string helpFile = ResolveHelpPath(_appPath);

					if (System.IO.File.Exists(helpFile))
					{
						Help.ShowHelp(this, helpFile, HelpNavigator.Topic, topic);

						// Prevent link follow
						e.ReturnValue = false;
					}
				}
			}
		}

		private static string ResolveHelpPath(string baseDir)
		{
			string[] helpFiles = new string[]
			{
				"MindFusion.Scheduling.chm",
				"MindFusion WinForms.chm"
			};

			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(baseDir);
			int i = 0;
			while (dirInfo != null)
			{
				string helpFile = System.IO.Path.Combine(dirInfo.FullName, helpFiles[i]);
				if (System.IO.File.Exists(helpFile))
					return helpFile;

				i++;
				if (i == helpFiles.Length)
				{
					i = 0;
					dirInfo = dirInfo.Parent;
				}
			}

			return string.Empty;
		}

		private void OnAbout(object sender, System.EventArgs e)
		{
			System.Reflection.Assembly assembly = System.Reflection.Assembly.GetAssembly(
				typeof(MindFusion.Scheduling.WinForms.Calendar));

			if (assembly == null)
				return;

			Type aboutFormType = assembly.GetType(
				"MindFusion.Scheduling.WinForms.AboutForm");

			if (aboutFormType == null)
				return;

			((Form)Activator.CreateInstance(aboutFormType)).ShowDialog(this);
		}

		private void OnExit(object sender, System.EventArgs e)
		{
			this.Close();
		}

		protected override void OnClosing(CancelEventArgs e)
		{
			e.Cancel = false;
			base.OnClosing(e);
		}

		private void _pnlBottom_SizeChanged(object sender, EventArgs e)
		{
			if (_pnlBottom.Height > 80)
				_pnlBottom.Height = 80;
		}

		private void _menuClear_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Items.Clear();
		}

		private void _menuLoad_Click(object sender, EventArgs e)
		{
			if (_openFileDialog.ShowDialog(this) == DialogResult.OK)
			{
				string ext = Path.GetExtension(_openFileDialog.FileName);
				try
				{
					if (ext == "sch")
						_calendar.Schedule.LoadFrom(_openFileDialog.FileName, ContentType.Binary);
					else
						_calendar.Schedule.LoadFrom(_openFileDialog.FileName, ContentType.Xml);
				}
				catch
				{
					MessageBox.Show("Invalid file format.");
				}

				_calendar.GroupType = GroupType.None;
				_calendar.Contacts.Clear();
				_calendar.Locations.Clear();
				_calendar.Tasks.Clear();

				// Invalidate
				_calendar.Invalidate();
			}
		}

		private void _menuSave_Click(object sender, EventArgs e)
		{
			if (_saveFileDialog.ShowDialog(this) == DialogResult.OK)
			{
				if (_saveFileDialog.FilterIndex == 0)
					_calendar.Schedule.SaveTo(_saveFileDialog.FileName, ContentType.Binary);
				else
					_calendar.Schedule.SaveTo(_saveFileDialog.FileName, ContentType.Xml);
			}
		}

		private void _menuExport_Click(object sender, EventArgs e)
		{
			if (_exportImageFileDialog.ShowDialog(this) == DialogResult.OK)
			{
				Bitmap bmp = _calendar.CreateImage(false);
				bmp.Save(_exportImageFileDialog.FileName);
				bmp.Dispose();
			}
		}

		private void _menuExportVisible_Click(object sender, EventArgs e)
		{
			if (_exportImageFileDialog.ShowDialog(this) == DialogResult.OK)
			{
				Bitmap bmp = _calendar.CreateImage(true);
				bmp.Save(_exportImageFileDialog.FileName);
				bmp.Dispose();
			}
		}

		private void _menuPrintPreview_Click(object sender, EventArgs e)
		{
			_calendar.PrintPreview();
		}

		private void _menuPrint_Click(object sender, EventArgs e)
		{
			_calendar.Print();
		}

		private void _menuPreviewReport_Click(object sender, EventArgs e)
		{
			Report report = new Report();
			ReportColumn column = null;

			column = report.CreateColumn();
			column.Property = "HeaderText";
			column.Header = "Item";
			column.Width = 100;
			report.Columns.Add(column);

			column = report.CreateColumn();
			column.Property = "StartTime";
			column.Header = "Start";
			column.Width = 80;
			column.Sort = Sort.Ascending;
			report.Columns.Add(column);

			column = report.CreateColumn();
			column.Property = "EndTime";
			column.Header = "End";
			column.Width = 80;
			column.Sort = Sort.Ascending;
			column.SortPriority = -1;
			report.Columns.Add(column);

			column = report.CreateColumn();
			column.Property = "DescriptionText";
			column.Header = "Description";
			column.Width = 250;
			column.Style.TextColor = Color.DarkGray;
			column.AlternativeStyle.TextColor = Color.DarkGray;
			report.Columns.Add(column);

			report.Options.AbsoluteColumnWidth = false;
			report.Schedule = _calendar.Schedule;

			PrintDocument doc = new PrintDocument();
			doc.DocumentName = "MindFusion.Scheduling Report";
			report.Preview(doc, _calendar.GetFirstVisibleDate(), _calendar.GetLastVisibleDate());
		}

		private void _menuEdit_DropDownOpened(object sender, EventArgs e)
		{
			_menuUndo.Enabled = _calendar.Schedule.CanUndo;
			_menuRedo.Enabled = _calendar.Schedule.CanRedo;
		}

		private void _menuUndo_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Undo();
		}

		private void _menuRedo_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Redo();
		}

		private void _menuContacts_Click(object sender, EventArgs e)
		{
			ContactsDialog form = new ContactsDialog(_calendar);
			form.ShowDialog();

			_calendar.BeginInit();

			// Remove contacts that no longer exist
			for (int i = 0; i < _calendar.Contacts.Count; )
			{
				Contact contact = _calendar.Contacts[i];

				if (!_calendar.Schedule.Contacts.Contains(contact))
					_calendar.Contacts.RemoveAt(i);
				else
					i++;
			}

			_calendar.EndInit();
		}

		private void _menuAppointments_Click(object sender, EventArgs e)
		{
			AppointmentsDialog form = new AppointmentsDialog(_calendar);

			form.ShowDialog();
		}

		private void _menuDaily_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.Timetable;
		}

		private void _menuWeekly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.List;
		}

		private void _menuMonthly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.SingleMonth;
		}

		private void _menuYearly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.MonthRange;
		}

		private void _menuCalendar_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.WeekRange;
		}

		private void _menuStandard_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Standard;
			CheckTimetableHeaderBrushes();
		}

		private void _menuWindows2003_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Windows2003;
			CheckTimetableHeaderBrushes();
		}

		private void _menuLila_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Lila;
			CheckTimetableHeaderBrushes();
		}

		private void _menuSilver_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Silver;
			CheckTimetableHeaderBrushes();
		}

		private void _menuVista_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Vista;
			CheckTimetableHeaderBrushes();
		}

		private void _menuLight_Click(object sender, EventArgs e)
		{
			_calendar.Theme = ThemeType.Light;
			CheckTimetableHeaderBrushes();
		}

		private void CheckTimetableHeaderBrushes()
		{
			// If it is horizontal timetable, adjust header brushes
			if (_calendar.CurrentView == CalendarView.Timetable &&
				_calendar.TimetableSettings.Orientation == Orientation.Horizontal)
			{
				_calendar.TimetableSettings.TimelineStyle.HeaderBrush = null;
				_calendar.TimetableSettings.Style.HeaderBrush = null;

				MindFusion.Drawing.Brush timelineBrush =
					_calendar.TimetableSettings.TimelineStyle.HeaderBrush;
				MindFusion.Drawing.Brush headerBrush =
					_calendar.TimetableSettings.Style.HeaderBrush;
				_calendar.TimetableSettings.TimelineStyle.HeaderBrush = headerBrush;
				_calendar.TimetableSettings.Style.HeaderBrush = timelineBrush;
			}
		}

		private void _menuTheme_Popup(object sender, EventArgs e)
		{
			_menuStandard.Checked = (_calendar.Theme == ThemeType.Standard);
			_menuWindows2003.Checked = (_calendar.Theme == ThemeType.Windows2003);
			_menuLila.Checked = (_calendar.Theme == ThemeType.Lila);
			_menuSilver.Checked = (_calendar.Theme == ThemeType.Silver);
			_menuVista.Checked = (_calendar.Theme == ThemeType.Vista);
			_menuLight.Checked = (_calendar.Theme == ThemeType.Light);
		}

		private void _menuEffects_Popup(object sender, EventArgs e)
		{
			_menuGlassEffect1.Checked = _calendar.ItemEffects.Contains(glassEffect) && glassEffect.Type == GlassEffectType.Type1;
			_menuGlassEffect2.Checked = _calendar.ItemEffects.Contains(glassEffect) && glassEffect.Type == GlassEffectType.Type2;
			_menuGlassEffect3.Checked = _calendar.ItemEffects.Contains(glassEffect) && glassEffect.Type == GlassEffectType.Type3;
			_menuGlassEffect4.Checked = _calendar.ItemEffects.Contains(glassEffect) && glassEffect.Type == GlassEffectType.Type4;
			_menuAeroEffect.Checked = _calendar.ItemEffects.Contains(aeroEffect);
		}

		private void _menuGlassEffect1_Click(object sender, EventArgs e)
		{
			if (!_calendar.ItemEffects.Contains(glassEffect) || glassEffect.Type != GlassEffectType.Type1)
			{
				if (!_calendar.ItemEffects.Contains(glassEffect))
					_calendar.ItemEffects.Add(glassEffect);
				glassEffect.Type = GlassEffectType.Type1;
				glassEffect.GlowColor = Color.White;
			}
			else
			{
				if (glassEffect.Type == GlassEffectType.Type1)
					_calendar.ItemEffects.Remove(glassEffect);
			}
		}

		private void _menuGlassEffect2_Click(object sender, EventArgs e)
		{
			if (!_calendar.ItemEffects.Contains(glassEffect) || glassEffect.Type != GlassEffectType.Type2)
			{
				if (!_calendar.ItemEffects.Contains(glassEffect))
					_calendar.ItemEffects.Add(glassEffect);
				glassEffect.Type = GlassEffectType.Type2;
				glassEffect.GlowColor = Color.White;
			}
			else
			{
				if (glassEffect.Type == GlassEffectType.Type2)
					_calendar.ItemEffects.Remove(glassEffect);
			}
		}

		private void _menuGlassEffect3_Click(object sender, EventArgs e)
		{
			if (!_calendar.ItemEffects.Contains(glassEffect) || glassEffect.Type != GlassEffectType.Type3)
			{
				if (!_calendar.ItemEffects.Contains(glassEffect))
					_calendar.ItemEffects.Add(glassEffect);
				glassEffect.Type = GlassEffectType.Type3;
				glassEffect.GlowColor = Color.White;
			}
			else
			{
				if (glassEffect.Type == GlassEffectType.Type3)
					_calendar.ItemEffects.Remove(glassEffect);
			}
		}

		private void _menuGlassEffect4_Click(object sender, EventArgs e)
		{
			if (!_calendar.ItemEffects.Contains(glassEffect) || glassEffect.Type != GlassEffectType.Type4)
			{
				if (!_calendar.ItemEffects.Contains(glassEffect))
					_calendar.ItemEffects.Add(glassEffect);
				glassEffect.Type = GlassEffectType.Type4;
				glassEffect.GlowColor = Color.Black;
			}
			else
			{
				if (glassEffect.Type == GlassEffectType.Type4)
					_calendar.ItemEffects.Remove(glassEffect);
			}
		}

		private void _menuAeroEffect_Click(object sender, EventArgs e)
		{
			if (!_calendar.ItemEffects.Contains(aeroEffect))
				_calendar.ItemEffects.Add(aeroEffect);
			else
				_calendar.ItemEffects.Remove(aeroEffect);
		}

		private void _stepsView_AfterSelect(object sender, TreeViewEventArgs e)
		{
			_lbInfo.Navigate("about:blank");
			_lbInfo.Document.OpenNew(false);
			_lbInfo.Document.Write("<html>");
			_lbInfo.Document.Write("<head>");
			_lbInfo.Document.Write("<style type=\"text/css\">");
			_lbInfo.Document.Write("body { font-family: Verdana, Arial, Helvetica, sans-serif; " +
				"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default; }");
			_lbInfo.Document.Write("</style>");
			_lbInfo.Document.Write("</head>");
			_lbInfo.Document.Write("</html>");
			_lbInfo.Document.Write("<body>");
			_lbInfo.Document.Write(_info[(int)e.Node.Tag]);
			_lbInfo.Document.Write("</body>");
			//_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
			//    "font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			_lbInfo.Refresh();

			//_lbInfo.Document.OpenNew(false);
			//_lbInfo.DocumentText = _info[(int)e.Node.Tag];
			//_lbInfo.Refresh();

			int tag = (int)e.Node.Tag;

			_calendar.BeginInit();

			if (tag / 100 == 0)
			{
				// Single month steps
				_calendar.CurrentView = CalendarView.SingleMonth;

				if (tag == 10)
				{
					// Interaction
					_holidayStyle = new Style();
					_holidayStyle.BorderTopWidth = 1;
					_holidayStyle.BorderLeftWidth = 1;
					_holidayStyle.BorderBottomWidth = 1;
					_holidayStyle.BorderRightWidth = 1;
					_holidayStyle.Image = _imageHoliday;
					_holidayStyle.ImageAlignment =
						MindFusion.Drawing.ImageAlignment.Left |
						MindFusion.Drawing.ImageAlignment.Top;

					_birthdayStyle = new Style();
					_birthdayStyle.BorderTopWidth = 1;
					_birthdayStyle.BorderLeftWidth = 1;
					_birthdayStyle.BorderBottomWidth = 1;
					_birthdayStyle.BorderRightWidth = 1;
					_birthdayStyle.Image = _imageBirthday;
					_birthdayStyle.ImageAlignment =
						MindFusion.Drawing.ImageAlignment.Left |
						MindFusion.Drawing.ImageAlignment.Top;
				}
			}

			if (tag / 100 == 1)
			{
				// Month range steps
				_calendar.CurrentView = CalendarView.MonthRange;
			}

			if (tag / 100 == 2)
			{
				// List view
				_calendar.CurrentView = CalendarView.List;

				if (tag == 210)
				{
					_calendar.ListViewSettings.Orientation = Orientation.Horizontal;
				}
				else if (tag == 220)
				{
					_calendar.ListViewSettings.Orientation = Orientation.Vertical;
				}
			}

			if (tag / 100 == 3)
			{
				// Week range
				_calendar.CurrentView = CalendarView.WeekRange;

				if (tag == 310)
				{
					_calendar.WeekRangeSettings.ViewStyle = WeekRangeViewStyle.WeekPerRow;
				}
				else if (tag == 320)
				{
					_calendar.WeekRangeSettings.ViewStyle = WeekRangeViewStyle.SingleWeek;
				}
			}

			if (tag / 100 == 4)
			{
				// Timetable
				_calendar.CurrentView = CalendarView.Timetable;

				_calendar.TimetableSettings.Style.HeaderBrush = null;
				_calendar.TimetableSettings.TimelineStyle.HeaderBrush = null;

				if (tag == 405)
				{
					_calendar.TimetableSettings.Orientation = Orientation.Horizontal;

					// Switch header brushes
					MindFusion.Drawing.Brush timelineBrush =
						_calendar.TimetableSettings.TimelineStyle.HeaderBrush;
					MindFusion.Drawing.Brush headerBrush =
						_calendar.TimetableSettings.Style.HeaderBrush;
					_calendar.TimetableSettings.TimelineStyle.HeaderBrush = headerBrush;
					_calendar.TimetableSettings.Style.HeaderBrush = timelineBrush;
				}
				else if (tag == 406)
				{
					_calendar.TimetableSettings.Orientation = Orientation.Vertical;
				}
				else if (tag == 420)
				{
					_calendar.TimetableSettings.Orientation = Orientation.Vertical;
				}
			}

			if (tag / 100 == 6)
			{
				_calendar.CurrentView = CalendarView.ResourceView;
				_calendar.ResourceViewSettings.VisibleRows = 3;

				// Ensure there are resources
				if (_calendar.GroupType != GroupType.GroupByContacts &&
					_calendar.GroupType != GroupType.GroupByLocations &&
					_calendar.GroupType != GroupType.GroupByResources &&
					_calendar.GroupType != GroupType.GroupByTasks)
					_calendar.GroupType = GroupType.GroupByContacts;
			}

			if (tag == 510 || tag == 520)
			{
				_calendar.InteractiveItemType = typeof(MyApp);
				_calendar.CurrentView = CalendarView.Timetable;
				_calendar.TimetableSettings.Orientation = Orientation.Vertical;
			}
			else
			{
				_calendar.InteractiveItemType = typeof(Appointment);
			}

			Item fe1 = _calendar.Schedule.Items["fe1"];
			if (fe1 != null)
			{
				fe1.Visible = (tag == 520);
				if (tag == 520)
					_calendar.EnsureVisible(fe1);
			}

			Item fe2 = _calendar.Schedule.Items["fe2"];
			if (fe2 != null)
			{
				fe2.Visible = (tag == 520);
				if (tag == 520)
					_calendar.EnsureVisible(fe2);
			}

			if (tag == 520)
				_calendar.ItemSettings.UseStyledText = State.Enabled;
			else
				_calendar.ItemSettings.UseStyledText = State.Disabled;

			// Update panels
			_pnlMonth.Visible = (tag == 0);
			MonthSettings s1 = _calendar.MonthSettings;
			_chkMonthNavigationButtons.Checked = (s1.HeaderStyle & MonthHeaderStyles.MonthButtons) > 0;
			_chkYearNavigationButtons.Checked = (s1.HeaderStyle & MonthHeaderStyles.YearButtons) > 0;
			_chkDayOfWeekHeader.Checked = s1.ShowDayOfWeek == State.Enabled;
			_chkWeekNumbers.Checked = s1.WeekHeaderStyle != MonthWeekHeaderStyle.None;
			_chkMonthShadow.Checked = s1.HeaderShadowStyle != ShadowStyle.None;
			_monthMainTrack.Value = s1.MainHeaderHeight;
			_monthSubTrack.Value = s1.SubHeaderHeight;
			_monthWeekTrack.Value = s1.WeekNumbersHeaderWidth;

			_pnlMonthAppearance.Visible = (tag == 20);

			_pnlYear.Visible = (tag == 100);
			MonthRangeSettings s2 = _calendar.MonthRangeSettings;
			_chkYearNavigation.Checked = (s2.HeaderStyle & MonthRangeHeaderStyles.Buttons) > 0;
			_numberOfMonthsTrack.Value = s2.NumberOfMonths;
			_monthsPerRowTrack.Value = s2.MonthsPerRow;
			_yearRowsTrack.Value = s2.VisibleRows;

			_pnlWeek.Visible = (tag == 200);
			ListViewSettings s3 = _calendar.ListViewSettings;
			_chkWeekHeaderShadow.Checked = (s3.HeaderShadowStyle == ShadowStyle.Fading);
			_weekHeaderSizeTrack.Value = s3.HeaderSize;
			_numberOfDaysTrack.Value = s3.NumberOfCells;
			_visibleDaysTrack.Value = s3.VisibleCells;

			_pnlCalendar.Visible = (tag == 300);
			WeekRangeSettings s4 = _calendar.WeekRangeSettings;
			_chkTimePeriodHeader.Checked = (s4.HeaderStyle == WeekRangeHeaderStyle.Title);
			_chkDayOfWeekHeader2.Checked = s4.ShowDayOfWeek == State.Enabled;
			_chkCalendarHeaderShadow.Checked = (s4.HeaderShadowStyle == ShadowStyle.Fading);
			_chkGroupWeekends.Checked = s4.GroupWeekends == State.Enabled;
			_calendarHeaderSizeTrack.Value = s4.TimePeriodHeaderHeight;
			_subHeaderSizeTrack.Value = s4.DayNamesHeaderHeight;
			_totalDaysTrack.Value = Math.Min(_totalDaysTrack.Maximum, Math.Max(_totalDaysTrack.Minimum, (int)(_calendar.EndDate - _calendar.Date).TotalDays));
			_visibleRowsTrack.Value = s4.VisibleRows;

			_pnlTimetable.Visible = (tag == 400);
			TimetableSettings s5 = _calendar.TimetableSettings;
			_timetableHeaderSizeTrack.Value = s5.MainHeaderSize;
			_timetableSubHeaderSize.Value = s5.SubHeaderSize;
			_chkTimetableHeaderShadow.Checked = s5.HeaderShadowStyle == ShadowStyle.Fading;
			_timelineSizeTrack.Value = s5.TimelineSize;
			_chkShowSecondTimeZone.Checked = s5.SecondTimelineStyle == Alignment.Near;
			_chkShowCurrentTime.Checked = s5.ShowCurrentTime == State.Enabled;
			_chkTimetableNavigationButtons.Checked = s5.ShowNavigationButtons == State.Enabled;
			_minutesPerCellTrack.Value = (int)s5.CellTime.TotalMinutes;
			_segmentSizeTrack.Value = s5.CellSize;

			_pnlTimeline.Visible = (tag == 422);

			_pnlResourceView.Visible = (tag == 600);

			_calendar.EndInit();

			// Make 06:00 at the top
			if (_pnlTimetable.Visible)
			{
				_calendar.ScrollPosition =
					new Point(_calendar.ScrollPosition.X, 12);
			}
		}

		private void _btnSetDateRange_Click(object sender, EventArgs e)
		{
			_calendar.BeginInit();

			DateRangeDialog dlg = new DateRangeDialog();
			DateCollection dates = _calendar.TimetableSettings.Dates;

			dlg.SetRange(dates[0], dates[dates.Count - 1]);
			dlg.SetTheme(_calendar.Theme);

			if (dlg.ShowDialog(this) == DialogResult.OK)
			{
				dates.Clear();

				DateTime date = dlg.StartDate;
				while (true)
				{
					dates.Add(date);
					date += new TimeSpan(TimeSpan.TicksPerDay);
					if (date > dlg.EndDate)
						break;
				}
			}

			_calendar.EndInit();
		}

		private void _calendar_DateClick(object sender, MindFusion.Scheduling.WinForms.ResourceDateEventArgs e)
		{
			int tag = (int)_stepsView.SelectedNode.Tag;

			switch (tag)
			{

				case 10: // Single month / interaction
				{
					if (e.Button == MouseButtons.Right)
					{
						Point mouse = _calendar.PointToClient(Control.MousePosition);

						// Remember the clicked date
						_clickedDate = e.Date;

						// Check if it is a holiday
						bool isHoliday = false;
						bool isBirthday = false;
						foreach (DateStyle style in _calendar.DayStyles)
						{
							if (style.From == e.Date)
							{
								if (style.Style.Image == _imageHoliday)
									isHoliday = true;
								else
									isBirthday = true;
								break;
							}
						}

						_menuHoliday.Checked = isHoliday;
						_menuBirthday.Checked = isBirthday;

						// Display the Holiday context menu
						_menuDate.Show(_calendar, mouse);
					}
				}
					break;

				case 600: // Resource view
				{
					if (e.Clicks == 2 && e.Button == MouseButtons.Left)
					{
						_calendar.ResetDrag();

						Contact c = _calendar.GetContactAt(_calendar.PointToClient(MousePosition));
						if (c == null)
							return;

						ResourceForm form = new ResourceForm();
						if (form.ShowDialog(this) == DialogResult.OK)
						{
							Appointment app = new Appointment();

							app.StartTime = e.Date;
							app.EndTime = e.Date + TimeSpan.FromDays(2);
							app.HeaderText = form.ResourceName;
							app.Contacts.Add(c);

							_calendar.Schedule.Items.Add(app);
						}
					}
				}
					break;

			}
		}

		private void _calendar_MonthHeaderClick(object sender, MindFusion.Scheduling.WinForms.DateEventArgs e)
		{
			if ((int)_stepsView.SelectedNode.Tag != 10)
				return;

			if (e.Button != MouseButtons.Left)
				return;

			Rectangle bounds = e.Bounds;

			_menuJanuary.Checked = false;
			_menuFebruary.Checked = false;
			_menuMarch.Checked = false;
			_menuApril.Checked = false;
			_menuMay.Checked = false;
			_menuJune.Checked = false;
			_menuJuly.Checked = false;
			_menuAugust.Checked = false;
			_menuSeptember.Checked = false;
			_menuOctober.Checked = false;
			_menuNovember.Checked = false;
			_menuDecember.Checked = false;

			switch (_calendar.Date.Month)
			{

				case 1:
					_menuJanuary.Checked = true;
					break;

				case 2:
					_menuFebruary.Checked = true;
					break;

				case 3:
					_menuMarch.Checked = true;
					break;

				case 4:
					_menuApril.Checked = true;
					break;

				case 5:
					_menuMay.Checked = true;
					break;

				case 6:
					_menuJune.Checked = true;
					break;

				case 7:
					_menuJuly.Checked = true;
					break;

				case 8:
					_menuAugust.Checked = true;
					break;

				case 9:
					_menuSeptember.Checked = true;
					break;

				case 10:
					_menuOctober.Checked = true;
					break;

				case 11:
					_menuNovember.Checked = true;
					break;

				case 12:
					_menuDecember.Checked = true;
					break;

			}

			// Display the menu in the center of the header
			_menuMonth.Show(_calendar,
				new Point(bounds.X + bounds.Width / 2, bounds.Y));
		}

		private void _calendar_RecurringItemDeleting(object sender, RecurringItemConfirmEventArgs e)
		{
			e.ConfirmOccurrence = true;
		}

		private void SetDate(DateTime newDate)
		{
			TimeSpan span = _calendar.EndDate - _calendar.Date;
			_calendar.Date = newDate;
			_calendar.EndDate = newDate.Add(span);
		}

		private void _menuJanuary_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 1, 1));
		}

		private void _menuFebruary_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 2, 1));
		}

		private void _menuMarch_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 3, 1));
		}

		private void _menuApril_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 4, 1));
		}

		private void _menuMay_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 5, 1));
		}

		private void _menuJune_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 6, 1));
		}

		private void _menuJuly_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 7, 1));
		}

		private void _menuAugust_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 8, 1));
		}

		private void _menuSeptember_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 9, 1));
		}

		private void _menuOctober_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 10, 1));
		}

		private void _menuNovember_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 11, 1));
		}

		private void _menuDecember_Click(object sender, EventArgs e)
		{
			SetDate(new DateTime(_calendar.Date.Year, 12, 1));
		}

		private void _menuHoliday_Click(object sender, EventArgs e)
		{
			// Make the clicked date a holiday if it is not and
			// not a holiday otherwise
			bool wasHoliday = false;
			foreach (DateStyle style in _calendar.DayStyles)
			{
				if (style.From == _clickedDate)
				{
					if (style.Style.Image == _imageHoliday)
						wasHoliday = true;

					_calendar.DayStyles.Remove(style);

					break;
				}
			}

			if (!wasHoliday)
			{
				DateStyle style = new DateStyle();
				style.From = _clickedDate;
				style.To = _clickedDate;
				style.Style = _holidayStyle;
				_calendar.DayStyles.Add(style);
			}

			_calendar.Invalidate();
		}

		private void _menuBirthday_Click(object sender, EventArgs e)
		{
			// Make the clicked date a birthday if it is not and
			// not a birthday otherwise
			bool wasBirthday = false;
			foreach (DateStyle style in _calendar.DayStyles)
			{
				if (style.From == _clickedDate)
				{
					if (style.Style.Image == _imageBirthday)
						wasBirthday = true;

					_calendar.DayStyles.Remove(style);

					break;
				}
			}

			if (!wasBirthday)
			{
				DateStyle style = new DateStyle();
				style.From = _clickedDate;
				style.To = _clickedDate;
				style.Style = _birthdayStyle;
				_calendar.DayStyles.Add(style);
			}

			_calendar.Invalidate();
		}

		private void _chkMonthNavigationButtons_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkMonthNavigationButtons.Checked)
				_calendar.MonthSettings.HeaderStyle |= MonthHeaderStyles.MonthButtons;
			else
				_calendar.MonthSettings.HeaderStyle &= ~MonthHeaderStyles.MonthButtons;
			_calendar.EndInit();
		}

		private void _chkYearNavigationButtons_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkYearNavigationButtons.Checked)
				_calendar.MonthSettings.HeaderStyle |= MonthHeaderStyles.YearButtons;
			else
				_calendar.MonthSettings.HeaderStyle &= ~MonthHeaderStyles.YearButtons;
			_calendar.EndInit();
		}

		private void _chkDayOfWeekHeader_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthSettings.ShowDayOfWeek =
				(_chkDayOfWeekHeader.Checked ? State.Enabled : State.Disabled);
			_calendar.EndInit();
		}

		private void _chkWeekNumbers_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkWeekNumbers.Checked)
				_calendar.MonthSettings.WeekHeaderStyle = MonthWeekHeaderStyle.Left;
			else
				_calendar.MonthSettings.WeekHeaderStyle = MonthWeekHeaderStyle.None;
			_calendar.EndInit();
		}

		private void _chkMonthShadow_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkMonthShadow.Checked)
				_calendar.MonthSettings.HeaderShadowStyle = ShadowStyle.Fading;
			else
				_calendar.MonthSettings.HeaderShadowStyle = ShadowStyle.None;
			_calendar.EndInit();
		}

		private void _monthMainTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthSettings.MainHeaderHeight = _monthMainTrack.Value;
			_calendar.EndInit();
		}

		private void _monthSubTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthSettings.SubHeaderHeight = _monthSubTrack.Value;
			_calendar.EndInit();
		}

		private void _monthWeekTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthSettings.WeekNumbersHeaderWidth = _monthWeekTrack.Value;
			_calendar.EndInit();
		}

		private void _chkYearNavigation_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkYearNavigation.Checked)
				_calendar.MonthRangeSettings.HeaderStyle |= MonthRangeHeaderStyles.Buttons;
			else
				_calendar.MonthRangeSettings.HeaderStyle &= ~MonthRangeHeaderStyles.Buttons;
			_calendar.EndInit();
		}

		private void _numberOfMonthsTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthRangeSettings.NumberOfMonths = _numberOfMonthsTrack.Value;
			_calendar.EndInit();
		}

		private void _monthsPerRowTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthRangeSettings.MonthsPerRow = _monthsPerRowTrack.Value;
			_calendar.EndInit();
		}

		private void _yearRowsTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.MonthRangeSettings.VisibleRows = _yearRowsTrack.Value;
			_calendar.EndInit();
		}

		private void _chkWeekHeaderShadow_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkWeekHeaderShadow.Checked)
				_calendar.ListViewSettings.HeaderShadowStyle = ShadowStyle.Fading;
			else
				_calendar.ListViewSettings.HeaderShadowStyle = ShadowStyle.None;
			_calendar.EndInit();
		}

		private void _weekHeaderSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.ListViewSettings.HeaderSize = _weekHeaderSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _numberOfDaysTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_numberOfDaysTrack.Value < _calendar.ListViewSettings.VisibleCells)
			{
				_calendar.ListViewSettings.VisibleCells = _numberOfDaysTrack.Value;
				_visibleDaysTrack.Value = _numberOfDaysTrack.Value;
			}
			_calendar.ListViewSettings.NumberOfCells = _numberOfDaysTrack.Value;
			_calendar.EndInit();
		}

		private void _visibleDaysTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_visibleDaysTrack.Value > _calendar.ListViewSettings.NumberOfCells)
			{
				_calendar.ListViewSettings.NumberOfCells = _visibleDaysTrack.Value;
				_numberOfDaysTrack.Value = _visibleDaysTrack.Value;
			}
			_calendar.ListViewSettings.VisibleCells = _visibleDaysTrack.Value;
			_calendar.EndInit();
		}

		private void _chkTimePeriodHeader_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkTimePeriodHeader.Checked)
				_calendar.WeekRangeSettings.HeaderStyle = WeekRangeHeaderStyle.Title;
			else
				_calendar.WeekRangeSettings.HeaderStyle = WeekRangeHeaderStyle.None;
			_calendar.EndInit();
		}

		private void _chkCalendarHeaderShadow_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkCalendarHeaderShadow.Checked)
				_calendar.WeekRangeSettings.HeaderShadowStyle = ShadowStyle.Fading;
			else
				_calendar.WeekRangeSettings.HeaderShadowStyle = ShadowStyle.None;
			_calendar.EndInit();
		}

		private void _chkDayOfWeekHeader2_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.WeekRangeSettings.ShowDayOfWeek =
				(_chkDayOfWeekHeader2.Checked ? State.Enabled : State.Disabled);
			_calendar.EndInit();
		}

		private void _chkGroupWeekends_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.WeekRangeSettings.GroupWeekends =
				(_chkGroupWeekends.Checked ? State.Enabled : State.Disabled);
			_calendar.EndInit();
		}

		private void _calendarHeaderSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.WeekRangeSettings.TimePeriodHeaderHeight = _calendarHeaderSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _subHeaderSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.WeekRangeSettings.DayNamesHeaderHeight = _subHeaderSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _totalDaysTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.EndDate = _calendar.Date + TimeSpan.FromDays(_totalDaysTrack.Value);
			_calendar.EndInit();
		}

		private void _visibleRowsTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.WeekRangeSettings.VisibleRows = _visibleRowsTrack.Value;
			_calendar.EndInit();
		}

		private void _timetableHeaderSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.MainHeaderSize = _timetableHeaderSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _timetableSubHeaderSize_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.SubHeaderSize = _timetableSubHeaderSize.Value;
			_calendar.EndInit();
		}

		private void _chkTimetableHeaderShadow_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			if (_chkTimetableHeaderShadow.Checked)
				_calendar.TimetableSettings.HeaderShadowStyle = ShadowStyle.Fading;
			else
				_calendar.TimetableSettings.HeaderShadowStyle = ShadowStyle.None;
			_calendar.EndInit();
		}

		private void _timelineSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.TimelineSize = _timelineSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _chkShowSecondTimeZone_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.SecondTimelineStyle =
				(_chkShowSecondTimeZone.Checked ? Alignment.Near : Alignment.None);
			_calendar.EndInit();
		}


		private void _chkShowCurrentTime_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.ShowCurrentTime =
				(_chkShowCurrentTime.Checked ? State.Enabled : State.Disabled);
			_calendar.EnsureVisible(DateTime.Now);
			_calendar.EndInit();
		}

		private void _chkTimetableNavigationButtons_CheckedChanged(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.ShowNavigationButtons =
				(_chkTimetableNavigationButtons.Checked ? State.Enabled : State.Disabled);
			_calendar.EndInit();
		}

		private void _minutesPerCellTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.CellTime = TimeSpan.FromMinutes(_minutesPerCellTrack.Value);
			_calendar.EndInit();
		}

		private void _segmentSizeTrack_Scroll(object sender, EventArgs e)
		{
			_calendar.BeginInit();
			_calendar.TimetableSettings.CellSize = _segmentSizeTrack.Value;
			_calendar.EndInit();
		}

		private void _calendar_Draw(object sender, MindFusion.Scheduling.WinForms.DrawEventArgs e)
		{
			int tag = (int)_stepsView.SelectedNode.Tag;
			if (tag == 20)
			{
				// SingleMonth custom drawing

				Pen penDark = new Pen(Color.LightSlateGray);
				Pen penLight = new Pen(Color.White);

				switch (e.Element)
				{

					case CustomDrawElements.MonthWeekNumbersHeaderCell:
					{
						if (_embelishMonthHeader)
						{
							if (e.Index != 5)
							{
								e.Graphics.DrawLine(penDark,
									e.Bounds.Left + 2, e.Bounds.Bottom - 1,
									e.Bounds.Right - 4, e.Bounds.Bottom - 1);
							}
							if (e.Index != 0)
							{
								e.Graphics.DrawLine(penLight,
									e.Bounds.Left + 3, e.Bounds.Top,
									e.Bounds.Right - 3, e.Bounds.Top);
							}
						}
					}
						break;

					case CustomDrawElements.MonthSubHeaderCell:
					{
						if (_embelishMonthHeader)
						{
							if (e.Index != 6)
							{
								e.Graphics.DrawLine(penDark,
									e.Bounds.Right - 1, e.Bounds.Top + 2,
									e.Bounds.Right - 1, e.Bounds.Bottom - 4);
							}
							if (e.Index != 0)
							{
								e.Graphics.DrawLine(penLight,
									e.Bounds.Left, e.Bounds.Top + 3,
									e.Bounds.Left, e.Bounds.Bottom - 3);
							}
						}
					}
						break;

				}

				penLight.Dispose();
				penDark.Dispose();
			}

			if (tag == 420)
			{
				// Timetable custom drawing

				switch (e.Element)
				{

					case CustomDrawElements.TimetableColumnHeader:
					{
						//if (e.Index < 50)
						{
							Rectangle bounds = e.Bounds;
							Image image = Images[(e.Index + 1) % Images.Length];

							e.Graphics.DrawImage(image, 
								bounds.X + 2, bounds.Y + bounds.Height / 2 - image.Height / 2);
						}
					}
						break;

					case CustomDrawElements.TimetableCell:
					{
						if (e.Date == DateTime.Today)
						{
							if (e.StartTime >= new TimeSpan(3, 20, 0) &&
								e.EndTime < new TimeSpan(5, 0, 0) ||
								e.StartTime >= new TimeSpan(6, 40, 0) &&
								e.EndTime < new TimeSpan(9, 0, 0))
							{
								Rectangle bounds = e.Bounds;
								bounds.Inflate(-1, -1);

								Brush brush = new SolidBrush(Color.FromArgb(255, 245, 210));
								e.Graphics.FillRectangle(brush, bounds);
								brush.Dispose();

								bounds.Inflate(-1, -1);
								bounds.Width -= 1;
								bounds.Height -= 1;

								Pen pen = new Pen(Color.Goldenrod);
								e.Graphics.DrawRectangle(pen, bounds);
								pen.Dispose();

								Image image = Resources.Image13;

								e.Graphics.DrawImage(image, bounds.X + 2,
									bounds.Y + bounds.Height / 2 - image.Height / 2);
							}
						}
					}
						break;

					case CustomDrawElements.TimetableWholeDayHeader:
					{
						if (e.Date == DateTime.Today + new TimeSpan(TimeSpan.TicksPerDay))
						{
							Brush brush = new HatchBrush(
								HatchStyle.Weave, Color.SteelBlue, Color.LightSteelBlue);
							e.Graphics.FillRectangle(brush, e.Bounds);
							brush.Dispose();

							Pen pen = new Pen(Color.SteelBlue);
							Rectangle bounds = e.Bounds;
							bounds.Width -= 1;
							bounds.Height -= 1;
							e.Graphics.DrawRectangle(pen, bounds);
							pen.Dispose();
						}
					}
						break;

				}
			}

			if (tag == 421)
			{
				switch (e.Element)
				{

					case CustomDrawElements.TimetableCell:
					{
						// Draw all workig cells in a custom fashion
						if (e.Date.DayOfWeek != DayOfWeek.Saturday &&
							e.Date.DayOfWeek != DayOfWeek.Sunday)
						{
							// Check if this cell is selected
							DateTime date = e.Date + e.StartTime;
							bool selected = _calendar.Selection.Contains(date);

							if (e.StartTime < TimeSpan.FromHours(_calendar.TimetableSettings.WorkTimeEndHour) &&
								e.EndTime > TimeSpan.FromHours(_calendar.TimetableSettings.WorkTimeStartHour))
							{
								Brush brush = null;
								if (selected)
								{
									brush = new HatchBrush(HatchStyle.Percent50,
										Color.Goldenrod, Color.Yellow);
								}
								else
								{
									brush = new HatchBrush(HatchStyle.Percent50,
										Color.Yellow, Color.White);
								}

								Rectangle bounds = e.Bounds;
								bounds.Inflate(-1, -1);

								e.Graphics.FillRectangle(brush, bounds);

								brush.Dispose();
							}
						}
					}
						break;

				}
			}

			if (tag == 422)
			{
				switch (e.Element)
				{

					case CustomDrawElements.TimetableTimelineCell:
					{
						if ((_embelishTimeline & 1) > 0)
						{
							Pen penDark = new Pen(Color.LightSlateGray);
							Pen penLight = new Pen(Color.White);

							Rectangle bounds = e.Bounds;

							// Take into account orientation and
							// right-to-left alignment
							if (_calendar.TimetableSettings.Orientation == Orientation.Vertical)
							{
								if (_calendar.RightToLeft == RightToLeft.Yes)
								{
									bounds.Width -= bounds.Width / 2;

									e.Graphics.DrawLine(penLight,
										bounds.Left + 3, bounds.Top,
										bounds.Right, bounds.Top);
									e.Graphics.DrawLine(penDark,
										bounds.Left + 4, bounds.Bottom - 1,
										bounds.Right, bounds.Bottom - 1);
								}
								else
								{
									bounds.X += bounds.Width / 2;
									bounds.Width -= bounds.Width / 2;

									e.Graphics.DrawLine(penLight,
										bounds.Left, bounds.Top,
										bounds.Right - 3, bounds.Top);
									e.Graphics.DrawLine(penDark,
										bounds.Left, bounds.Bottom - 1,
										bounds.Right - 4, bounds.Bottom - 1);
								}
							}
							else
							{
								bounds.Y += bounds.Height / 2;
								bounds.Height -= bounds.Height / 2;

								if (_calendar.RightToLeft == RightToLeft.Yes)
									bounds.X += 1;

								e.Graphics.DrawLine(penLight,
									bounds.Left, bounds.Top,
									bounds.Left, bounds.Bottom - 3);
								e.Graphics.DrawLine(penDark,
									bounds.Right - 1, bounds.Top,
									bounds.Right - 1, bounds.Bottom - 4);
							}

							penLight.Dispose();
							penDark.Dispose();
						}
					}
						break;

					case CustomDrawElements.TimetableTimelineHourCell:
					{
						if ((_embelishTimeline & 1) > 0)
						{
							Pen penDark = new Pen(Color.LightSlateGray);
							Pen penLight = new Pen(Color.White);

							Rectangle bounds = e.Bounds;

							if (_calendar.TimetableSettings.Orientation == Orientation.Vertical)
							{
								e.Graphics.DrawLine(penLight,
									bounds.Left + 3, bounds.Top,
									bounds.Right - 3, bounds.Top);
								e.Graphics.DrawLine(penDark,
									bounds.Left + 2, bounds.Bottom - 1,
									bounds.Right - 4, bounds.Bottom - 1);
							}
							else
							{
								if (_calendar.RightToLeft == RightToLeft.Yes)
									bounds.X += 1;

								e.Graphics.DrawLine(penLight,
									bounds.Left, bounds.Top + 3,
									bounds.Left, bounds.Bottom - 3);
								e.Graphics.DrawLine(penDark,
									bounds.Right - 1, bounds.Top + 2,
									bounds.Right - 1, bounds.Bottom - 4);
							}

							penLight.Dispose();
							penDark.Dispose();
						}

						if ((_embelishTimeline & 2) > 1)
						{
							Pen penDark = new Pen(Color.LightSlateGray);
							Pen penLight = new Pen(Color.White);

							Rectangle bounds = e.Bounds;
							bounds.Width -= 1;
							bounds.Height -= 1;

							if (_calendar.RightToLeft == RightToLeft.Yes)
								bounds.X += 1;

							e.Graphics.DrawLine(penLight,
								bounds.Left, bounds.Top,
								bounds.Right, bounds.Top);
							e.Graphics.DrawLine(penLight,
								bounds.Left, bounds.Top,
								bounds.Left, bounds.Bottom);
							e.Graphics.DrawLine(penDark,
								bounds.Right, bounds.Top,
								bounds.Right, bounds.Bottom);
							e.Graphics.DrawLine(penDark,
								bounds.Left, bounds.Bottom,
								bounds.Right, bounds.Bottom);

							penLight.Dispose();
							penDark.Dispose();
						}
					}
						break;

				}
			}
		}

		private void _btnButtons_Click(object sender, EventArgs e)
		{
			if (_calendar.ControlAppearance == ControlAppearance.System)
			{
				MessageBox.Show(this, "You cannot change the appearance of the system controls. " +
					"To toggle to the custom controls, change the theme to Windows2003, Lila, Silver, Vista, or Light.",
					"Change Button Style", MessageBoxButtons.OK, MessageBoxIcon.Information);
				return;
			}

			ControlStyle style = _calendar.ControlStyle;

			_calendar.BeginInit();

			MindFusion.Drawing.LinearGradientBrush fillBrush =
				new MindFusion.Drawing.LinearGradientBrush(Color.Empty, Color.Empty);

			fillBrush.Angle = 90;
			fillBrush.InterpolationColors = new ColorBlend(3);
			fillBrush.InterpolationColors.Positions = new float[] { 0, 0.5f, 1 };
			fillBrush.InterpolationColors.Colors =
				new Color[] { Color.White, Color.Goldenrod, Color.Gold };

			MindFusion.Drawing.LinearGradientBrush overBrush =
				new MindFusion.Drawing.LinearGradientBrush(Color.Empty, Color.Empty);

			overBrush.Angle = 90;
			overBrush.InterpolationColors = new ColorBlend(3);
			overBrush.InterpolationColors.Positions = new float[] { 0, 0.5f, 1 };
			overBrush.InterpolationColors.Colors =
				new Color[] { Color.White, Color.Gold, Color.Yellow };

			MindFusion.Drawing.LinearGradientBrush downBrush =
				new MindFusion.Drawing.LinearGradientBrush(Color.Empty, Color.Empty);

			downBrush.Angle = 90;
			downBrush.InterpolationColors = new ColorBlend(3);
			downBrush.InterpolationColors.Positions = new float[] { 0, 0.5f, 1 };
			downBrush.InterpolationColors.Colors =
				new Color[] { Color.Goldenrod, Color.DarkGoldenrod, Color.Gold };

			// Apply the settings
			style.ButtonBorderColor = Color.DarkGoldenrod;
			style.ButtonFillBrush = fillBrush;
			style.ButtonFillBrushOver = overBrush;
			style.ButtonFillBrushDown = downBrush;

			_calendar.EndInit();
		}

		private void _btnHeaderEmbellishments_Click(object sender, EventArgs e)
		{
			_embelishMonthHeader = true;
			_calendar.Invalidate();
		}

		private void _btnAddFormatting_Click(object sender, EventArgs e)
		{
			if (_style1 == null)
			{
				_style1 = new DateStyle();
				_style1.Style.BorderTopWidth = 1;
				_style1.Style.BorderLeftWidth = 1;
				_style1.Style.BorderBottomWidth = 1;
				_style1.Style.BorderRightWidth = 1;
				_style1.Style.Brush = new MindFusion.Drawing.HatchBrush(
					HatchStyle.SmallCheckerBoard, Color.PowderBlue, Color.LightSteelBlue);
				_style1.From = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 10);
				_style1.To = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 14);

				_style2 = new DateStyle();
				_style2.Style.HeaderFont = new Font(
					"Times New Roman", 24, FontStyle.Italic);
				_style2.Style.HeaderTextColor = Color.Red;
				_style2.From = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 21);
				_style2.To = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 23);

				_style3 = new DateStyle();
				_style3.Style.Image = Resources.Image33;
				_style3.Style.ImageAlignment = MindFusion.Drawing.ImageAlignment.Left;
				_style3.From = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 19);
				_style3.To = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 20);

				_style4 = new DateStyle();
				_style4.Style.BorderTopWidth = 2;
				_style4.Style.BorderLeftWidth = 2;
				_style4.Style.BorderBottomWidth = 2;
				_style4.Style.BorderRightWidth = 2;
				_style4.Style.BorderTopColor = Color.Gainsboro;
				_style4.Style.BorderLeftColor = Color.Gainsboro;
				_style4.Style.BorderBottomColor = Color.LightSlateGray;
				_style4.Style.BorderRightColor = Color.LightSlateGray;
				_style4.From = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 1);
				_style4.To = new DateTime(_calendar.Date.Year, _calendar.Date.Month, 4);

				_calendar.DayStyles.Add(_style1);
				_calendar.DayStyles.Add(_style2);
				_calendar.DayStyles.Add(_style3);
				_calendar.DayStyles.Add(_style4);

				_calendar.Invalidate();
			}
		}

		private void _btnClear_Click(object sender, EventArgs e)
		{
			_calendar.BeginInit();

			// Reset settings
			ControlStyle style = _calendar.ControlStyle;

			style.ButtonBorderColor = Color.Empty;
			style.ButtonFillBrush = null;
			style.ButtonFillBrushOver = null;
			style.ButtonFillBrushDown = null;

			// Clear formattings
			if (_style1 != null)
			{
				_calendar.DayStyles.Remove(_style1);
				_calendar.DayStyles.Remove(_style2);
				_calendar.DayStyles.Remove(_style3);
				_calendar.DayStyles.Remove(_style4);

				_style1 = null;
				_style2 = null;
				_style3 = null;
				_style4 = null;
			}

			_embelishMonthHeader = false;

			//_calendar.GroupType = GroupType.None;
			//_calendar.Contacts.Clear();
			//_calendar.Locations.Clear();
			//_calendar.Tasks.Clear();
			//_calendar.Schedule.Clear();

			_calendar.EndInit();
		}

		private void _btnAddEmbelishments1_Click(object sender, EventArgs e)
		{
			_embelishTimeline |= 1;
			_calendar.Invalidate();
		}

		private void _btnAddEmbelishments2_Click(object sender, EventArgs e)
		{
			_embelishTimeline |= 2;
			_calendar.Invalidate();
		}

		private void _btnClearEmbelishments_Click(object sender, EventArgs e)
		{
			_embelishTimeline = 0;
			_calendar.Invalidate();
		}

		private void _calendar_ItemClick(object sender, MindFusion.Scheduling.WinForms.ItemMouseEventArgs e)
		{
			if (e.Button == MouseButtons.Left && e.Clicks == 2)
			{
				_calendar.ResetDrag();

				// Item is double clicked -> display the appointment editing form
				AppointmentForm form = new AppointmentForm(_calendar.Schedule);
				form.SetAppointment(e.Item as Appointment);

				DialogResult result = form.ShowDialog(this);
				if (result == DialogResult.Abort)
				{
					// If it is a recurring item, it is not found withing
					// the collection of items. In order to delete it
					// we need to mark it as an exception
					if (e.Item.RecurrenceState == RecurrenceState.Occurrence ||
						e.Item.RecurrenceState == RecurrenceState.Exception)
						e.Item.Recurrence.MarkException(e.Item, true);
					else
						_calendar.Schedule.Items.Remove(e.Item);
				}

				_calendar.Invalidate();
			}
		}

		private void AddScheduleData()
		{
			_calendar.BeginInit();

			// Create some events
			DateCollection dates = _calendar.TimetableSettings.Dates;

			Appointment app = null;
			Recurrence recurrence = null;
			DateTime date = DateTime.Today;
			Random random = new Random(DateTime.Now.Millisecond);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 8, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 10, 30, 0);
			app.HeaderText = "Meet George";
			app.DescriptionText = "This is the second time I promise George. This time I should go.";
			//app.Style = this._eventStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 13, 15, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 14, 00, 0);
			app.HeaderText = "Visit the dentist";
			//app.Style = this._eventStyle;
			_calendar.Schedule.Items.Add(app);

			// Add a recurring appointment
			date = dates[0];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 12, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 13, 30, 0);
			app.HeaderText = "Lunch with Laura";
			app.DescriptionText = "Never forget the appointment with the boss.";

			// Each working day, for an eternity
			recurrence = new Recurrence();
			recurrence.Pattern = RecurrencePattern.Daily;
			recurrence.DailyRecurrence = DailyRecurrence.EveryWorkday;
			recurrence.StartDate = date;
			recurrence.RecurrenceEnd = RecurrenceEnd.Never;
			app.Recurrence = recurrence;

			//app.Style = this._eventStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.AllDayEvent = true;
			app.StartTime = date;
			app.EndTime = date;
			app.HeaderText = "William's birthday";
			//app.Style = this._freeStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 10, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 16, 00, 0);
			app.HeaderText = "Have fun!";
			app.DescriptionText = "Some leisure time.";
			//app.Style = this._freeStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 18, 20, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 18, 35, 0);
			app.HeaderText = "Prepare the dinner!";
			//app.Style = this._taskStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 17, 00, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 17, 45, 0);
			app.HeaderText = "Get the children from the kindergarten!";
			//app.Style = this._taskStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 17, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 21, 0, 0);
			app.HeaderText = "Arrange the house payments!";
			//app.Style = this._taskStyle;
			_calendar.Schedule.Items.Add(app);

			date = dates[random.Next() % dates.Count];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 7, 30, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 8, 20, 0);
			app.HeaderText = "Drive kids to school!";
			//app.Style = this._taskStyle;
			_calendar.Schedule.Items.Add(app);


			// Add some contacts
			Contact c = null;

			c = new Contact();
			c.FirstName = "Tom";
			c.LastName = "Miles";
			_calendar.Schedule.Contacts.Add(c);
			_calendar.Contacts.Add(c);

			c = new Contact();
			c.FirstName = "Jimmy";
			c.LastName = "King";
			_calendar.Schedule.Contacts.Add(c);
			_calendar.Contacts.Add(c);

			c = new Contact();
			c.FirstName = "Elisabeth";
			c.LastName = "Tailor";
			_calendar.Schedule.Contacts.Add(c);
			_calendar.Contacts.Add(c);

			// Create an item with a styled text...
			date = dates[0];
			app = new Appointment();
			app.StartTime = new DateTime(date.Year, date.Month, date.Day, 0, 0, 0);
			app.EndTime = new DateTime(date.Year, date.Month, date.Day, 5, 0, 0);
			app.HeaderText = "Formatted event";
			app.DescriptionText = "The description of appointments can contain " +
				"<b>bold</b>, <i>italic</i> and <u>underlined</u> texts as well as " +
				"<color=#00ff33>text</color> <color=#ccffcc>in</color> " +
				"<color=#000000>various</color> <color=#ff00cc>colors</color>," +
				"<sup>superscript</sup> and <sub>subscript</sub>.";
			app.Id = "fe1";
			app.Visible = false;
			_calendar.Schedule.Items.Add(app);

			// ...and item with styled text for the first contact
			app = app.Clone() as Appointment;
			app.Id = "fe2";
			app.Contacts.Add(_calendar.Schedule.Contacts[0]);
			_calendar.Schedule.Items.Add(app);

			// Add some appointments associated with various contacts
			// so that grouped views are not initially empty
			for (int i = 0; i < 5; i++)
			{
				c = _calendar.Schedule.Contacts[random.Next() % _calendar.Schedule.Contacts.Count];
				date = dates[0] + TimeSpan.FromDays(random.Next() % 10);
				app = new Appointment();
				app.StartTime = date;
				app.EndTime = date + TimeSpan.FromDays(2);
				app.HeaderText = "Event for " + c.FirstName;
				app.Contacts.Add(c);
				_calendar.Schedule.Items.Add(app);
			}

			_calendar.EndInit();
		}

		private void _menuLeftToRight_Click(object sender, EventArgs e)
		{
			_calendar.RightToLeft = RightToLeft.No;
		}

		private void _menuRightToLeft_Click(object sender, EventArgs e)
		{
			_calendar.RightToLeft = RightToLeft.Yes;
		}

		private void _menuLayout_Popup(object sender, EventArgs e)
		{
			_menuLeftToRight.Checked =  _calendar.RightToLeft == RightToLeft.No;
			_menuRightToLeft.Checked =  _calendar.RightToLeft == RightToLeft.Yes;
		}

		private void _chkShowLanes_CheckedChanged(object sender, EventArgs e)
		{
			if (_chkShowLanes.Checked)
				_calendar.ResourceViewSettings.ViewStyle = ResourceViewStyle.Lanes;
			else
				_calendar.ResourceViewSettings.ViewStyle = ResourceViewStyle.General;
		}

		private void _chkGroupHeaders_CheckedChanged(object sender, EventArgs e)
		{
			if (_chkGroupHeaders.Checked)
				_calendar.ResourceViewSettings.GroupRowHeader = State.Enabled;
			else
				_calendar.ResourceViewSettings.GroupRowHeader = State.Disabled;
		}

		private void _chkExpandableRows_CheckedChanged(object sender, EventArgs e)
		{
			if (_chkExpandableRows.Checked)
				_calendar.ResourceViewSettings.ExpandableRows = State.Enabled;
			else
				_calendar.ResourceViewSettings.ExpandableRows = State.Disabled;
		}

		private void _calendar_VisibleDateChanged(object sender, MindFusion.Scheduling.WinForms.DateChangedEventArgs e)
		{
			// Ensure the end date is 60 days after the start date
			_calendar.EndDate = e.NewDate + TimeSpan.FromDays(60);
		}


		private static Image[] Images;


		private string _appPath;
		private InfoHolder _info;

		private DateTime _clickedDate;
		private Style _holidayStyle;
		private Style _birthdayStyle;

		private bool _embelishMonthHeader;
		private DateStyle _style1;
		private DateStyle _style2;
		private DateStyle _style3;
		private DateStyle _style4;

		/// <summary>
		/// 0 - no, 1 - emb.1, 2 - emb.2;
		/// </summary>
		private int _embelishTimeline;

		private Style _taskStyle;
		private Style _eventStyle;
		private Style _freeStyle;

		private Image _imageHoliday;
		private Image _imageBirthday;

		private GlassEffect glassEffect;
		private AeroEffect aeroEffect;
	}
}
