//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Demo
{
	/// <summary>
	/// A custom appointment editor.
	/// </summary>
	public partial class MyEditor : System.Windows.Forms.UserControl, IItemEditor
	{
		/// <summary>
		/// Initializes a new instance of the MyEditor class.
		/// </summary>
		public MyEditor()
		{
			InitializeComponent();
		}

		/// <summary>
		/// IItemEditor.StartEdit implementation.
		/// </summary>
		public void StartEdit(ItemEditContext context)
		{
			_context = context;

			_textHeader.Text = context.Item.HeaderText;
			_textDescription.Text = context.Item.DescriptionText;

			_textHeader.Focus();
			_textHeader.Select(_textHeader.Text.Length, 0);
		}

		/// <summary>
		/// IItemEditor.EndEdit implementation.
		/// </summary>
		public void EndEdit(ItemEditContext context, bool accept)
		{
			if (accept)
			{
				context.Item.HeaderText = _textHeader.Text;
				context.Item.DescriptionText = _textDescription.Text;

				context.Accept();
			}
			else
			{
				context.Cancel();
			}
		}

		protected override bool ProcessDialogKey(Keys keyData)
		{
			bool result = base.ProcessDialogKey(keyData);

			if ((keyData & Keys.KeyCode) == Keys.Escape)
			{
				EndEdit(_context, false);
				return true;
			}
			else if ((keyData & Keys.KeyCode) == Keys.Enter)
			{
				if ((ModifierKeys & Keys.Control) > 0)
				{
					EndEdit(_context, true);
					return true;
				}
			}

			return result;
		}


		private void _btnOk_Click(object sender, System.EventArgs e)
		{
			EndEdit(_context, true);
		}

		private void _btnCancel_Click(object sender, System.EventArgs e)
		{
			EndEdit(_context, false);
		}


		public new string Text
		{
			get { return _textHeader.Text; }
		}


		private ItemEditContext _context;
	}
}
